==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/databricks/kotlin/inputs/WorkspaceProviderAuthorizationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.databricks.kotlin.inputs

import com.pulumi.azurenative.databricks.inputs.WorkspaceProviderAuthorizationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The workspace provider authorization.
 * @property principalId The provider's principal identifier. This is the identity that the provider will use to call ARM to manage the workspace resources.
 * @property roleDefinitionId The provider's role definition identifier. This role will define all the permissions that the provider must have on the workspace's container resource group. This role definition cannot have permission to delete the resource group.
 */
public data class WorkspaceProviderAuthorizationArgs(
    public val principalId: Output<String>,
    public val roleDefinitionId: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.databricks.inputs.WorkspaceProviderAuthorizationArgs> {
    override fun toJava(): com.pulumi.azurenative.databricks.inputs.WorkspaceProviderAuthorizationArgs =
        com.pulumi.azurenative.databricks.inputs.WorkspaceProviderAuthorizationArgs.builder()
            .principalId(principalId.applyValue({ args0 -> args0 }))
            .roleDefinitionId(roleDefinitionId.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [WorkspaceProviderAuthorizationArgs].
 */
@PulumiTagMarker
public class WorkspaceProviderAuthorizationArgsBuilder internal constructor() {
    private var principalId: Output<String>? = null

    private var roleDefinitionId: Output<String>? = null

    /**
     * @param value The provider's principal identifier. This is the identity that the provider will use to call ARM to manage the workspace resources.
     */
    @JvmName("jpfmaruqmclxtxax")
    public suspend fun principalId(`value`: Output<String>) {
        this.principalId = value
    }

    /**
     * @param value The provider's role definition identifier. This role will define all the permissions that the provider must have on the workspace's container resource group. This role definition cannot have permission to delete the resource group.
     */
    @JvmName("iwersptseqyydndt")
    public suspend fun roleDefinitionId(`value`: Output<String>) {
        this.roleDefinitionId = value
    }

    /**
     * @param value The provider's principal identifier. This is the identity that the provider will use to call ARM to manage the workspace resources.
     */
    @JvmName("gtugjdlcdiyturut")
    public suspend fun principalId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.principalId = mapped
    }

    /**
     * @param value The provider's role definition identifier. This role will define all the permissions that the provider must have on the workspace's container resource group. This role definition cannot have permission to delete the resource group.
     */
    @JvmName("elfnnqgvnxfvgiiw")
    public suspend fun roleDefinitionId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.roleDefinitionId = mapped
    }

    internal fun build(): WorkspaceProviderAuthorizationArgs = WorkspaceProviderAuthorizationArgs(
        principalId = principalId ?: throw PulumiNullFieldException("principalId"),
        roleDefinitionId = roleDefinitionId ?: throw PulumiNullFieldException("roleDefinitionId"),
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/databricks/kotlin/inputs/WorkspaceProviderAuthorizationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.databricks.kotlin.inputs

import com.pulumi.azurenative.databricks.inputs.WorkspaceProviderAuthorizationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The workspace provider authorization.
 * @property principalId The provider's principal identifier. This is the identity that the provider will use to call ARM to manage the workspace resources.
 * @property roleDefinitionId The provider's role definition identifier. This role will define all the permissions that the provider must have on the workspace's container resource group. This role definition cannot have permission to delete the resource group.
 */
public data class WorkspaceProviderAuthorizationArgs(
    public val principalId: Output<String>,
    public val roleDefinitionId: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.databricks.inputs.WorkspaceProviderAuthorizationArgs> {
    override fun toJava(): com.pulumi.azurenative.databricks.inputs.WorkspaceProviderAuthorizationArgs =
        com.pulumi.azurenative.databricks.inputs.WorkspaceProviderAuthorizationArgs.builder()
            .principalId(principalId.applyValue({ args0 -> args0 }))
            .roleDefinitionId(roleDefinitionId.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [WorkspaceProviderAuthorizationArgs].
 */
@PulumiTagMarker
public class WorkspaceProviderAuthorizationArgsBuilder internal constructor() {
    private var principalId: Output<String>? = null

    private var roleDefinitionId: Output<String>? = null

    /**
     * @param value The provider's principal identifier. This is the identity that the provider will use to call ARM to manage the workspace resources.
     */
    @JvmName("pyhqjpfqbnetmfve")
    public suspend fun principalId(`value`: Output<String>) {
        this.principalId = value
    }

    /**
     * @param value The provider's role definition identifier. This role will define all the permissions that the provider must have on the workspace's container resource group. This role definition cannot have permission to delete the resource group.
     */
    @JvmName("tdqfsqawhdutgcrn")
    public suspend fun roleDefinitionId(`value`: Output<String>) {
        this.roleDefinitionId = value
    }

    /**
     * @param value The provider's principal identifier. This is the identity that the provider will use to call ARM to manage the workspace resources.
     */
    @JvmName("gqgrceiffjwikjqs")
    public suspend fun principalId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.principalId = mapped
    }

    /**
     * @param value The provider's role definition identifier. This role will define all the permissions that the provider must have on the workspace's container resource group. This role definition cannot have permission to delete the resource group.
     */
    @JvmName("nlgwaltrvpkibray")
    public suspend fun roleDefinitionId(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.roleDefinitionId = mapped
    }

    internal fun build(): WorkspaceProviderAuthorizationArgs = WorkspaceProviderAuthorizationArgs(
        principalId = principalId ?: throw PulumiNullFieldException("principalId"),
        roleDefinitionId = roleDefinitionId ?: throw PulumiNullFieldException("roleDefinitionId"),
    )
}
